# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tasks_common.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x11task_status.proto\"\x80\x05\n\x07TaskRaw\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cowner_pod_id\x18\x03 \x01(\t\x12\x17\n\x0fparent_task_ids\x18\x04 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x05 \x03(\t\x12\x1b\n\x13\x65xpected_output_ids\x18\x06 \x03(\t\x12\x14\n\x0cretry_of_ids\x18\x07 \x03(\t\x12;\n\x06status\x18\x08 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x16\n\x0estatus_message\x18\t \x01(\t\x12\x31\n\x07options\x18\n \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csubmitted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07pod_ttl\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x06output\x18\x10 \x01(\x0b\x32).armonik.api.grpc.v1.tasks.TaskRaw.Output\x1a(\n\x06Output\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\xba\x02\n\x0bTaskSummary\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12;\n\x06status\x18\x04 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x65rror\x18\x08 \x01(\t\"\xc2\x08\n\x10ListTasksRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x42\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x32.armonik.api.grpc.v1.tasks.ListTasksRequest.Filter\x12>\n\x04sort\x18\x04 \x01(\x0b\x32\x30.armonik.api.grpc.v1.tasks.ListTasksRequest.Sort\x12\x13\n\x0bwith_errors\x18\x05 \x01(\x08\x1a\x8a\x03\n\x06\x46ilter\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12;\n\x06status\x18\x02 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x31\n\rcreated_after\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0e\x63reated_before\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rstarted_after\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0estarted_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65nded_after\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x65nded_before\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x9e\x01\n\x04Sort\x12G\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x38.armonik.api.grpc.v1.tasks.ListTasksRequest.OrderByField\x12M\n\tdirection\x18\x02 \x01(\x0e\x32:.armonik.api.grpc.v1.tasks.ListTasksRequest.OrderDirection\"\xdf\x01\n\x0cOrderByField\x12\x1e\n\x1aORDER_BY_FIELD_UNSPECIFIED\x10\x00\x12\x1a\n\x16ORDER_BY_FIELD_TASK_ID\x10\x01\x12\x1d\n\x19ORDER_BY_FIELD_SESSION_ID\x10\x02\x12\x19\n\x15ORDER_BY_FIELD_STATUS\x10\x03\x12\x1d\n\x19ORDER_BY_FIELD_CREATED_AT\x10\x04\x12\x1d\n\x19ORDER_BY_FIELD_STARTED_AT\x10\x05\x12\x1b\n\x17ORDER_BY_FIELD_ENDED_AT\x10\x06\"d\n\x0eOrderDirection\x12\x1f\n\x1bORDER_DIRECTION_UNSPECIFIED\x10\x00\x12\x17\n\x13ORDER_DIRECTION_ASC\x10\x01\x12\x18\n\x14ORDER_DIRECTION_DESC\x10\x02\"z\n\x11ListTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x0eGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"C\n\x0fGetTaskResponse\x12\x30\n\x04task\x18\x01 \x01(\x0b\x32\".armonik.api.grpc.v1.tasks.TaskRaw\"&\n\x12\x43\x61ncelTasksRequest\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"L\n\x13\x43\x61ncelTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\"&\n\x13GetResultIdsRequest\x12\x0f\n\x07task_id\x18\x01 \x03(\t\"\xa1\x01\n\x14GetResultIdsResponse\x12S\n\x0ctask_results\x18\x01 \x03(\x0b\x32=.armonik.api.grpc.v1.tasks.GetResultIdsResponse.MapTaskResult\x1a\x34\n\rMapTaskResult\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x12\n\nresult_ids\x18\x02 \x03(\tB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Tasksb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Tasks'
  _TASKRAW._serialized_start=117
  _TASKRAW._serialized_end=757
  _TASKRAW_OUTPUT._serialized_start=717
  _TASKRAW_OUTPUT._serialized_end=757
  _TASKSUMMARY._serialized_start=760
  _TASKSUMMARY._serialized_end=1074
  _LISTTASKSREQUEST._serialized_start=1077
  _LISTTASKSREQUEST._serialized_end=2167
  _LISTTASKSREQUEST_FILTER._serialized_start=1284
  _LISTTASKSREQUEST_FILTER._serialized_end=1678
  _LISTTASKSREQUEST_SORT._serialized_start=1681
  _LISTTASKSREQUEST_SORT._serialized_end=1839
  _LISTTASKSREQUEST_ORDERBYFIELD._serialized_start=1842
  _LISTTASKSREQUEST_ORDERBYFIELD._serialized_end=2065
  _LISTTASKSREQUEST_ORDERDIRECTION._serialized_start=2067
  _LISTTASKSREQUEST_ORDERDIRECTION._serialized_end=2167
  _LISTTASKSRESPONSE._serialized_start=2169
  _LISTTASKSRESPONSE._serialized_end=2291
  _GETTASKREQUEST._serialized_start=2293
  _GETTASKREQUEST._serialized_end=2326
  _GETTASKRESPONSE._serialized_start=2328
  _GETTASKRESPONSE._serialized_end=2395
  _CANCELTASKSREQUEST._serialized_start=2397
  _CANCELTASKSREQUEST._serialized_end=2435
  _CANCELTASKSRESPONSE._serialized_start=2437
  _CANCELTASKSRESPONSE._serialized_end=2513
  _GETRESULTIDSREQUEST._serialized_start=2515
  _GETRESULTIDSREQUEST._serialized_end=2553
  _GETRESULTIDSRESPONSE._serialized_start=2556
  _GETRESULTIDSRESPONSE._serialized_end=2717
  _GETRESULTIDSRESPONSE_MAPTASKRESULT._serialized_start=2665
  _GETRESULTIDSRESPONSE_MAPTASKRESULT._serialized_end=2717
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: results_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import results_common_pb2 as results__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15results_service.proto\x12\x1b\x61rmonik.api.grpc.v1.results\x1a\x14results_common.proto2\xf8\x01\n\x07Results\x12r\n\x0bListResults\x12/.armonik.api.grpc.v1.results.ListResultsRequest\x1a\x30.armonik.api.grpc.v1.results.ListResultsResponse\"\x00\x12y\n\x0eGetOwnerTaskId\x12\x32.armonik.api.grpc.v1.results.GetOwnerTaskIdRequest\x1a\x33.armonik.api.grpc.v1.results.GetOwnerTaskIdResponseB\x1e\xaa\x02\x1b\x41rmoniK.Api.gRPC.V1.Resultsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'results_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\033ArmoniK.Api.gRPC.V1.Results'
  _RESULTS._serialized_start=77
  _RESULTS._serialized_end=325
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: objects.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\robjects.proto\x12\x13\x61rmonik.api.grpc.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x11task_status.proto\"\x07\n\x05\x45mpty\"\xf3\x02\n\x0bTaskOptions\x12>\n\x07options\x18\x01 \x03(\x0b\x32-.armonik.api.grpc.v1.TaskOptions.OptionsEntry\x12/\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0bmax_retries\x18\x03 \x01(\x05\x12\x10\n\x08priority\x18\x04 \x01(\x05\x12\x14\n\x0cpartition_id\x18\x05 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x06 \x01(\t\x12\x1b\n\x13\x61pplication_version\x18\x07 \x01(\t\x12\x1d\n\x15\x61pplication_namespace\x18\x08 \x01(\t\x12\x1b\n\x13\x61pplication_service\x18\t \x01(\t\x12\x13\n\x0b\x65ngine_type\x18\n \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x15\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\",\n\rConfiguration\x12\x1b\n\x13\x64\x61ta_chunk_max_size\x18\x01 \x01(\x05\"\x88\x01\n\x06Output\x12(\n\x02ok\x18\x02 \x01(\x0b\x32\x1a.armonik.api.grpc.v1.EmptyH\x00\x12\x32\n\x05\x65rror\x18\x03 \x01(\x0b\x32!.armonik.api.grpc.v1.Output.ErrorH\x00\x1a\x18\n\x05\x45rror\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\tB\x06\n\x04type\"W\n\x0bTaskRequest\x12\x1c\n\x14\x65xpected_output_keys\x18\x01 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x02 \x03(\t\x12\x0f\n\x07payload\x18\x03 \x01(\x0c\"C\n\x13InitKeyedDataStream\x12\r\n\x03key\x18\x01 \x01(\tH\x00\x12\x15\n\x0blast_result\x18\x02 \x01(\x08H\x00\x42\x06\n\x04type\"<\n\tDataChunk\x12\x0e\n\x04\x64\x61ta\x18\x01 \x01(\x0cH\x00\x12\x17\n\rdata_complete\x18\x02 \x01(\x08H\x00\x42\x06\n\x04type\"L\n\x11TaskRequestHeader\x12\x1c\n\x14\x65xpected_output_keys\x18\x01 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x02 \x03(\t\"h\n\x0fInitTaskRequest\x12\x38\n\x06header\x18\x01 \x01(\x0b\x32&.armonik.api.grpc.v1.TaskRequestHeaderH\x00\x12\x13\n\tlast_task\x18\x02 \x01(\x08H\x00\x42\x06\n\x04type\"\'\n\x06TaskId\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\"\x1e\n\nTaskIdList\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"Y\n\x0bStatusCount\x12;\n\x06status\x18\x01 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"9\n\x05\x43ount\x12\x30\n\x06values\x18\x01 \x03(\x0b\x32 .armonik.api.grpc.v1.StatusCount\"3\n\rResultRequest\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x01(\t\"5\n\x11TaskOutputRequest\x12\x0f\n\x07session\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\t\"Y\n\x05\x45rror\x12@\n\x0btask_status\x18\x01 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x0e\n\x06\x64\x65tail\x18\x02 \x01(\t\"H\n\tTaskError\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12*\n\x06\x65rrors\x18\x02 \x03(\x0b\x32\x1a.armonik.api.grpc.v1.Error\"9\n\x08TaskList\x12-\n\x08task_ids\x18\x01 \x03(\x0b\x32\x1b.armonik.api.grpc.v1.TaskId\"}\n\x10TaskIdWithStatus\x12,\n\x07task_id\x18\x01 \x01(\x0b\x32\x1b.armonik.api.grpc.v1.TaskId\x12;\n\x06status\x18\x02 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatusB\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'objects_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _TASKOPTIONS_OPTIONSENTRY._options = None
  _TASKOPTIONS_OPTIONSENTRY._serialized_options = b'8\001'
  _EMPTY._serialized_start=89
  _EMPTY._serialized_end=96
  _TASKOPTIONS._serialized_start=99
  _TASKOPTIONS._serialized_end=470
  _TASKOPTIONS_OPTIONSENTRY._serialized_start=424
  _TASKOPTIONS_OPTIONSENTRY._serialized_end=470
  _SESSION._serialized_start=472
  _SESSION._serialized_end=493
  _CONFIGURATION._serialized_start=495
  _CONFIGURATION._serialized_end=539
  _OUTPUT._serialized_start=542
  _OUTPUT._serialized_end=678
  _OUTPUT_ERROR._serialized_start=646
  _OUTPUT_ERROR._serialized_end=670
  _TASKREQUEST._serialized_start=680
  _TASKREQUEST._serialized_end=767
  _INITKEYEDDATASTREAM._serialized_start=769
  _INITKEYEDDATASTREAM._serialized_end=836
  _DATACHUNK._serialized_start=838
  _DATACHUNK._serialized_end=898
  _TASKREQUESTHEADER._serialized_start=900
  _TASKREQUESTHEADER._serialized_end=976
  _INITTASKREQUEST._serialized_start=978
  _INITTASKREQUEST._serialized_end=1082
  _TASKID._serialized_start=1084
  _TASKID._serialized_end=1123
  _TASKIDLIST._serialized_start=1125
  _TASKIDLIST._serialized_end=1155
  _STATUSCOUNT._serialized_start=1157
  _STATUSCOUNT._serialized_end=1246
  _COUNT._serialized_start=1248
  _COUNT._serialized_end=1305
  _RESULTREQUEST._serialized_start=1307
  _RESULTREQUEST._serialized_end=1358
  _TASKOUTPUTREQUEST._serialized_start=1360
  _TASKOUTPUTREQUEST._serialized_end=1413
  _ERROR._serialized_start=1415
  _ERROR._serialized_end=1504
  _TASKERROR._serialized_start=1506
  _TASKERROR._serialized_end=1578
  _TASKLIST._serialized_start=1580
  _TASKLIST._serialized_end=1637
  _TASKIDWITHSTATUS._serialized_start=1639
  _TASKIDWITHSTATUS._serialized_end=1764
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: task_status.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11task_status.proto\x12\x1f\x61rmonik.api.grpc.v1.task_status*\xb3\x02\n\nTaskStatus\x12\x1b\n\x17TASK_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14TASK_STATUS_CREATING\x10\x01\x12\x19\n\x15TASK_STATUS_SUBMITTED\x10\x02\x12\x1a\n\x16TASK_STATUS_DISPATCHED\x10\x03\x12\x19\n\x15TASK_STATUS_COMPLETED\x10\x04\x12\x15\n\x11TASK_STATUS_ERROR\x10\x05\x12\x17\n\x13TASK_STATUS_TIMEOUT\x10\x06\x12\x1a\n\x16TASK_STATUS_CANCELLING\x10\x07\x12\x19\n\x15TASK_STATUS_CANCELLED\x10\x08\x12\x1a\n\x16TASK_STATUS_PROCESSING\x10\t\x12\x19\n\x15TASK_STATUS_PROCESSED\x10\nB\x16\xaa\x02\x13\x41rmoniK.Api.gRPC.V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'task_status_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\023ArmoniK.Api.gRPC.V1'
  _TASKSTATUS._serialized_start=55
  _TASKSTATUS._serialized_end=362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: results_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import result_status_pb2 as result__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14results_common.proto\x12\x1b\x61rmonik.api.grpc.v1.results\x1a\x13result_status.proto\"\x99\x01\n\tResultRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x12\n\ncreated_at\x18\x05 \x01(\t\"\xc0\x05\n\x12ListResultsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x46\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x36.armonik.api.grpc.v1.results.ListResultsRequest.Filter\x12\x42\n\x04sort\x18\x04 \x01(\x0b\x32\x34.armonik.api.grpc.v1.results.ListResultsRequest.Sort\x1a\xb1\x01\n\x06\x46ilter\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rowner_task_id\x18\x03 \x01(\t\x12?\n\x06status\x18\x04 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x15\n\rcreated_after\x18\x05 \x01(\t\x12\x16\n\x0e\x63reated_before\x18\x06 \x01(\t\x1a\x9a\x01\n\x04Sort\x12H\n\x05\x66ield\x18\x01 \x01(\x0e\x32\x39.armonik.api.grpc.v1.results.ListResultsRequest.SortField\x12H\n\x05order\x18\x02 \x01(\x0e\x32\x39.armonik.api.grpc.v1.results.ListResultsRequest.SortOrder\"p\n\tSortField\x12\x1a\n\x16SORT_FIELD_UNSPECIFIED\x10\x00\x12\x0e\n\nSESSION_ID\x10\x01\x12\x08\n\x04NAME\x10\x02\x12\x11\n\rOWNER_TASK_ID\x10\x03\x12\n\n\x06STATUS\x10\x04\x12\x0e\n\nCREATED_AT\x10\x05\":\n\tSortOrder\x12\x1a\n\x16SORT_ORDER_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41SC\x10\x01\x12\x08\n\x04\x44\x45SC\x10\x02\"~\n\x13ListResultsResponse\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.results.ResultRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\">\n\x15GetOwnerTaskIdRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tresult_id\x18\x02 \x03(\t\"\xb9\x01\n\x16GetOwnerTaskIdResponse\x12V\n\x0bresult_task\x18\x01 \x03(\x0b\x32\x41.armonik.api.grpc.v1.results.GetOwnerTaskIdResponse.MapResultTask\x12\x12\n\nsession_id\x18\x02 \x01(\t\x1a\x33\n\rMapResultTask\x12\x11\n\tresult_id\x18\x01 \x01(\t\x12\x0f\n\x07task_id\x18\x02 \x01(\tB\x1e\xaa\x02\x1b\x41rmoniK.Api.gRPC.V1.Resultsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'results_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\033ArmoniK.Api.gRPC.V1.Results'
  _RESULTRAW._serialized_start=75
  _RESULTRAW._serialized_end=228
  _LISTRESULTSREQUEST._serialized_start=231
  _LISTRESULTSREQUEST._serialized_end=935
  _LISTRESULTSREQUEST_FILTER._serialized_start=427
  _LISTRESULTSREQUEST_FILTER._serialized_end=604
  _LISTRESULTSREQUEST_SORT._serialized_start=607
  _LISTRESULTSREQUEST_SORT._serialized_end=761
  _LISTRESULTSREQUEST_SORTFIELD._serialized_start=763
  _LISTRESULTSREQUEST_SORTFIELD._serialized_end=875
  _LISTRESULTSREQUEST_SORTORDER._serialized_start=877
  _LISTRESULTSREQUEST_SORTORDER._serialized_end=935
  _LISTRESULTSRESPONSE._serialized_start=937
  _LISTRESULTSRESPONSE._serialized_end=1063
  _GETOWNERTASKIDREQUEST._serialized_start=1065
  _GETOWNERTASKIDREQUEST._serialized_end=1127
  _GETOWNERTASKIDRESPONSE._serialized_start=1130
  _GETOWNERTASKIDRESPONSE._serialized_end=1315
  _GETOWNERTASKIDRESPONSE_MAPRESULTTASK._serialized_start=1264
  _GETOWNERTASKIDRESPONSE_MAPRESULTTASK._serialized_end=1315
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import results_common_pb2 as results__common__pb2


class ResultsStub(object):
    """*
    The ResultsService provides methods for interacting with results
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListResults = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/ListResults',
                request_serializer=results__common__pb2.ListResultsRequest.SerializeToString,
                response_deserializer=results__common__pb2.ListResultsResponse.FromString,
                )
        self.GetOwnerTaskId = channel.unary_unary(
                '/armonik.api.grpc.v1.results.Results/GetOwnerTaskId',
                request_serializer=results__common__pb2.GetOwnerTaskIdRequest.SerializeToString,
                response_deserializer=results__common__pb2.GetOwnerTaskIdResponse.FromString,
                )


class ResultsServicer(object):
    """*
    The ResultsService provides methods for interacting with results
    """

    def ListResults(self, request, context):
        """*
        Get a results list using pagination, filters and sorting
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOwnerTaskId(self, request, context):
        """*
        Get the id of the task that should produce the result
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResultsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListResults': grpc.unary_unary_rpc_method_handler(
                    servicer.ListResults,
                    request_deserializer=results__common__pb2.ListResultsRequest.FromString,
                    response_serializer=results__common__pb2.ListResultsResponse.SerializeToString,
            ),
            'GetOwnerTaskId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOwnerTaskId,
                    request_deserializer=results__common__pb2.GetOwnerTaskIdRequest.FromString,
                    response_serializer=results__common__pb2.GetOwnerTaskIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.results.Results', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Results(object):
    """*
    The ResultsService provides methods for interacting with results
    """

    @staticmethod
    def ListResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/ListResults',
            results__common__pb2.ListResultsRequest.SerializeToString,
            results__common__pb2.ListResultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOwnerTaskId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.results.Results/GetOwnerTaskId',
            results__common__pb2.GetOwnerTaskIdRequest.SerializeToString,
            results__common__pb2.GetOwnerTaskIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import objects_pb2 as objects__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gent_common.proto\x12\x19\x61rmonik.api.grpc.v1.agent\x1a\robjects.proto\"\xc4\x02\n\x11\x43reateTaskRequest\x12P\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x38.armonik.api.grpc.v1.agent.CreateTaskRequest.InitRequestH\x00\x12\x39\n\tinit_task\x18\x02 \x01(\x0b\x32$.armonik.api.grpc.v1.InitTaskRequestH\x00\x12\x36\n\x0ctask_payload\x18\x03 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1a\x45\n\x0bInitRequest\x12\x36\n\x0ctask_options\x18\x01 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptionsB\x06\n\x04type\"\xe3\x03\n\x0f\x43reateTaskReply\x12]\n\x14\x63reation_status_list\x18\x01 \x01(\x0b\x32=.armonik.api.grpc.v1.agent.CreateTaskReply.CreationStatusListH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x04 \x01(\t\x1aT\n\x08TaskInfo\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpected_output_keys\x18\x02 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x03 \x03(\t\x1au\n\x0e\x43reationStatus\x12H\n\ttask_info\x18\x01 \x01(\x0b\x32\x33.armonik.api.grpc.v1.agent.CreateTaskReply.TaskInfoH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x42\x08\n\x06Status\x1aj\n\x12\x43reationStatusList\x12T\n\x11\x63reation_statuses\x18\x01 \x03(\x0b\x32\x39.armonik.api.grpc.v1.agent.CreateTaskReply.CreationStatusB\n\n\x08Response\"7\n\x0b\x44\x61taRequest\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\"\x90\x02\n\tDataReply\x12\x1b\n\x13\x63ommunication_token\x18\x01 \x01(\t\x12\x39\n\x04init\x18\x02 \x01(\x0b\x32).armonik.api.grpc.v1.agent.DataReply.InitH\x00\x12.\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x0f\n\x05\x65rror\x18\x04 \x01(\tH\x00\x1a\x62\n\x04Init\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x0f\n\x05\x65rror\x18\x03 \x01(\tH\x00\x42\x0c\n\nhas_resultB\x06\n\x04type\"\x97\x01\n\x06Result\x12\x38\n\x04init\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.InitKeyedDataStreamH\x00\x12.\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\tB\x06\n\x04type\"m\n\x0bResultReply\x12\x1b\n\x13\x63ommunication_token\x18\x03 \x01(\t\x12(\n\x02Ok\x18\x01 \x01(\x0b\x32\x1a.armonik.api.grpc.v1.EmptyH\x00\x12\x0f\n\x05\x45rror\x18\x02 \x01(\tH\x00\x42\x06\n\x04typeB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Agentb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Agent'
  _CREATETASKREQUEST._serialized_start=65
  _CREATETASKREQUEST._serialized_end=389
  _CREATETASKREQUEST_INITREQUEST._serialized_start=312
  _CREATETASKREQUEST_INITREQUEST._serialized_end=381
  _CREATETASKREPLY._serialized_start=392
  _CREATETASKREPLY._serialized_end=875
  _CREATETASKREPLY_TASKINFO._serialized_start=552
  _CREATETASKREPLY_TASKINFO._serialized_end=636
  _CREATETASKREPLY_CREATIONSTATUS._serialized_start=638
  _CREATETASKREPLY_CREATIONSTATUS._serialized_end=755
  _CREATETASKREPLY_CREATIONSTATUSLIST._serialized_start=757
  _CREATETASKREPLY_CREATIONSTATUSLIST._serialized_end=863
  _DATAREQUEST._serialized_start=877
  _DATAREQUEST._serialized_end=932
  _DATAREPLY._serialized_start=935
  _DATAREPLY._serialized_end=1207
  _DATAREPLY_INIT._serialized_start=1101
  _DATAREPLY_INIT._serialized_end=1199
  _RESULT._serialized_start=1210
  _RESULT._serialized_end=1361
  _RESULTREPLY._serialized_start=1363
  _RESULTREPLY._serialized_end=1472
# @@protoc_insertion_point(module_scope)
